# Imagetosketch
![Author](https://img.shields.io/badge/author-aaneloy-blue)
[![MIT](https://img.shields.io/badge/license-MIT-5eba00.svg)](https://github.com/aaneloy/Image_to_sketch/main/LICENSE.txt)
[![Contributions welcome](https://img.shields.io/badge/contributions-welcome-brightgreen.svg?style=flat)](https://github.com/aaneloy/Image_to_sketch)
[![Stars](https://img.shields.io/github/stars/aaneloy/data-scaler.svg?style=social)](https://github.com/aaneloy/Image_to_sketch/stargazers)

Python open-source library to convert color/ B&amp;W image to pencil sketch

## Author: [Asif Ahmed Neloy](https://aaneloy.ca/)

## Installation:
```
pip install ImagetoSketch==0.1.3

```

## Usage

```python

#installation
!pip install ImagetoSketch==0.1.3

#import
from ImagetoSketch import *

#specify image directory:
ImagetoSketch(r'C:\Users\neloy\OneDrive\GitHub\Image_to_sketch\src\images\demo_2.png')

```

## Sample output
![Original Image](https://github.com/aaneloy/Image_to_sketch/blob/main/src/images/demo_2.png "Original Image") ![Sketched Image](https://github.com/aaneloy/Image_to_sketch/blob/main/src/images/sketch_2.png "Sketched Image")




For details see this [notebook](https://github.com/aaneloy/scaler_selector/blob/main/src/test.ipynb)

## License
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)